Module: Moobooks

Defined in:
lib/moobooks/version.rb,
lib/moobooks/plush.rb

Overview

Namespace for all classes in this gem.

Author:

  • Maxine Michalski

Since:

  • 0.1.0

Defined Under Namespace

Classes: Plush, UnsupportedEngineError

Constant Summary collapse

MAJOR =

Since:

  • 0.1.0

0
MINOR =

Since:

  • 0.1.0

2
PATCH =

Since:

  • 0.1.0

0
NAME =

Since:

  • 0.1.0

'moobooks'
VERSION =

Since:

  • 0.1.0

"#{MAJOR}.#{MINOR}.#{PATCH}"
DESCRIPTION =

Since:

  • 0.1.0

'A framework and CLI to create and manage ebook '\
"accounts.\nKeep in mind that actual accounts need to "\
'be created manually, but can be linked with this tool.'