Module: Moobooks
- Defined in:
- lib/moobooks/version.rb,
lib/moobooks/plush.rb
Overview
Namespace for all classes in this gem.
Defined Under Namespace
Classes: Plush, UnsupportedEngineError
Constant Summary collapse
- MAJOR =
0- MINOR =
2- PATCH =
0- NAME =
'moobooks'- VERSION =
"#{MAJOR}.#{MINOR}.#{PATCH}"- DESCRIPTION =
'A framework and CLI to create and manage ebook '\ "accounts.\nKeep in mind that actual accounts need to "\ 'be created manually, but can be linked with this tool.'